searchNodes=[{"ref":"StructyRecord.html","title":"StructyRecord","type":"module","doc":"StructyRecord provides a Struct-like interface for your Records. Use your record&#39;s macros in the same module where it is defined! Access and update fields in your record through named macro calls. Create and update records at runtime (not limited to compile time). Calculate 1-based indexes to access record fields in :ets tables."},{"ref":"StructyRecord.html#defrecord/3","title":"StructyRecord.defrecord/3","type":"macro","doc":"Defines a module named alias that is also a Record composed of fields. Parameters alias is the name of the module being defined. It also serves as the tag parameter of Record.defrecord/3, which helps identify the record. fields specifies the shape of the record being defined. It is either: a list of Atom field names whose default values are always nil a Keyword list of field names along with their own default values do_block is an optional block of code that is passed into defmodule/2. It allows you to extend the module being defined with your own custom code, which has compile-time access to all the guards and macros described below. Results The defined module provides the following guards, macros, and functions. Guards: is_record/1 to check if argument loosely matches this record&#39;s shape Macros: record?/1 to check if argument strictly matches this record&#39;s shape record/0 to create a new record with default values for all fields record/1 to create a new record with the given fields and values record/1 to get the zero-based index of the given field in a record record/1 to convert the given record into a Keyword list record/2 to get the value of a given field in a given record record/2 to update an existing record with the given fields and values ${field}/1 to get the value of a specific field in a given record ${field}/2 to set the value of a specific field in a given record keypos/1 to get the 1-based index of the given field in a record Functions: record!/1 to create a new record at runtime with the given fields and values record!/2 to update an existing record with the given fields and values Examples Activate this macro in your environment: require StructyRecord Define a structy record for a rectangle: StructyRecord.defrecord Rectangle, [:width, :height] do def area(r=record()) do width(r) * height(r) end def perimeter(record(width: w, height: h)) do 2 * (w + h) end def square?(record(width: same, height: same)), do: true def square?(_), do: false end Activate its macros in your environment: use Rectangle Create instances of your structy record: rect = Rectangle.record() #-&gt; {Rectangle, nil, nil} no_h = Rectangle.record(width: 1) #-&gt; {Rectangle, 1, nil} no_w = Rectangle.record(height: 2) #-&gt; {Rectangle, nil, 2} wide = Rectangle.record(width: 10, height: 5) #-&gt; {Rectangle, 10, 5} tall = Rectangle.record(width: 4, height: 25) #-&gt; {Rectangle, 4, 25} even = Rectangle.record(width: 10, height: 10) #-&gt; {Rectangle, 10, 10} Get values of fields in those instances: tall |&gt; Rectangle.height() #-&gt; 25 tall |&gt; Rectangle.record(:height) #-&gt; 25 Rectangle.record(height: h) = tall; h #-&gt; 25 Set values of fields in those instances: even |&gt; Rectangle.width(1) #-&gt; {Rectangle, 1, 10} even |&gt; Rectangle.record(width: 1) #-&gt; {Rectangle, 1, 10} even |&gt; Rectangle.width(1) |&gt; Rectangle.height(2) #-&gt; {Rectangle, 1, 2} even |&gt; Rectangle.record(width: 1, height: 2) #-&gt; {Rectangle, 1, 2} Use your custom code on those instances: rect |&gt; Rectangle.area() #-&gt; (ArithmeticError) bad argument in arithmetic expression: nil * nil no_h |&gt; Rectangle.area() #-&gt; (ArithmeticError) bad argument in arithmetic expression: 1 * nil no_w |&gt; Rectangle.area() #-&gt; (ArithmeticError) bad argument in arithmetic expression: nil * 2 wide |&gt; Rectangle.area() #-&gt; 50 tall |&gt; Rectangle.area() #-&gt; 100 even |&gt; Rectangle.area() #-&gt; 100 rect |&gt; Rectangle.perimeter() #-&gt; (ArithmeticError) bad argument in arithmetic expression: nil + nil no_h |&gt; Rectangle.perimeter() #-&gt; (ArithmeticError) bad argument in arithmetic expression: 1 + nil no_w |&gt; Rectangle.perimeter() #-&gt; (ArithmeticError) bad argument in arithmetic expression: nil + 2 wide |&gt; Rectangle.perimeter() #-&gt; 30 tall |&gt; Rectangle.perimeter() #-&gt; 58 even |&gt; Rectangle.perimeter() #-&gt; 40 rect |&gt; Rectangle.square?() #-&gt; true no_h |&gt; Rectangle.square?() #-&gt; false no_w |&gt; Rectangle.square?() #-&gt; false wide |&gt; Rectangle.square?() #-&gt; false tall |&gt; Rectangle.square?() #-&gt; false even |&gt; Rectangle.square?() #-&gt; true"},{"ref":"readme.html","title":"StructyRecord","type":"extras","doc":"StructyRecord StructyRecord provides a Struct-like interface for your Records. Use your record&#39;s macros in the same module where it is defined! Access and update fields in your record through named macro calls. Create and update records at runtime (not limited to compile time). Calculate 1-based indexes to access record fields in :ets tables. To get started, see the documentation for StructyRecord.defrecord/3: iex&gt; h StructyRecord.defrecord"},{"ref":"readme.html#installation","title":"StructyRecord - Installation","type":"extras","doc":"If available in Hex, the package can be installed by adding structy_record to your list of dependencies in mix.exs: def deps do [ {:structy_record, &quot;~&gt; 0.1.0&quot;} ] end Documentation can be generated with ExDoc and published on HexDocs. Once published, the docs can be found at https://hexdocs.pm/structy_record."},{"ref":"readme.html#license","title":"StructyRecord - License","type":"extras","doc":"Like my work? 👍 Please spare a life today as thanks! 🐮🐷🐔🐟🙊✌💞✨ For 💕 ethics, 🌎 environment, and 💪 health: learn more at link above. 🙇🙏 Copyright 2019 Suraj N. Kurapati https://github.com/sunaku Distributed under the terms of the ISC license (see the LICENSE file)."}]